"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.postGraphQLClassicIdsInflection = exports.postGraphQLInflection = exports.defaultInflection = undefined;

var _assign = require("babel-runtime/core-js/object/assign");

var _assign2 = _interopRequireDefault(_assign);

var _slicedToArray2 = require("babel-runtime/helpers/slicedToArray");

var _slicedToArray3 = _interopRequireDefault(_slicedToArray2);

var _pluralize = require("pluralize");

var _pluralize2 = _interopRequireDefault(_pluralize);

var _upperFirst = require("lodash/upperFirst");

var _upperFirst2 = _interopRequireDefault(_upperFirst);

var _camelCase = require("lodash/camelCase");

var _camelCase2 = _interopRequireDefault(_camelCase);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var constantCaseAll = function constantCaseAll(str) {
  return str.replace(/[^a-zA-Z0-9_]+/g, "_").replace(/[A-Z]+/g, "_$&").replace(/__+/g, "_").replace(/^[^a-zA-Z0-9]+/, "").replace(/^[0-9]/, "_$&") // GraphQL enums must not start with a number
  .toUpperCase();
};


var formatInsideUnderscores = function formatInsideUnderscores(fn) {
  return function (str) {
    var matches = str.match(/^(_*)([\s\S]*?)(_*)$/);
    if (!matches) {
      throw new Error("Impossible?"); // Satiate Flow
    }

    var _matches = (0, _slicedToArray3.default)(matches, 4),
        start = _matches[1],
        middle = _matches[2],
        end = _matches[3];

    return `${start}${fn(middle)}${end}`;
  };
};

var upperFirst = formatInsideUnderscores(_upperFirst2.default);
var camelCase = formatInsideUnderscores(_camelCase2.default);
var constantCase = formatInsideUnderscores(constantCaseAll);

var defaultInflection = exports.defaultInflection = {
  pluralize: _pluralize2.default,
  argument(name, index) {
    return camelCase(name || `arg${index}`);
  },
  orderByType(typeName) {
    return upperFirst(camelCase(`${(0, _pluralize2.default)(typeName)}-order-by`));
  },
  orderByEnum(name, ascending, _table, _schema) {
    return constantCase(`${name}_${ascending ? "asc" : "desc"}`);
  },
  domainType(name) {
    return upperFirst(camelCase(name));
  },
  enumName(value) {
    return value;
  },
  enumType(name) {
    return upperFirst(camelCase(name));
  },
  conditionType(typeName) {
    return upperFirst(camelCase(`${typeName}-condition`));
  },
  inputType(typeName) {
    return upperFirst(camelCase(`${typeName}-input`));
  },
  rangeBoundType(typeName) {
    return upperFirst(camelCase(`${typeName}-range-bound`));
  },
  rangeType(typeName) {
    return upperFirst(camelCase(`${typeName}-range`));
  },
  patchType(typeName) {
    return upperFirst(camelCase(`${typeName}-patch`));
  },
  patchField(itemName) {
    return camelCase(`${itemName}-patch`);
  },
  tableName(name, _schema) {
    return camelCase(_pluralize2.default.singular(name));
  },
  tableNode(name, _schema) {
    return camelCase(_pluralize2.default.singular(name));
  },
  allRows(name, schema) {
    return camelCase(`all-${this.pluralize(this.tableName(name, schema))}`);
  },
  functionName(name, _schema) {
    return camelCase(name);
  },
  functionPayloadType(name, _schema) {
    return upperFirst(camelCase(`${name}-payload`));
  },
  functionInputType(name, _schema) {
    return upperFirst(camelCase(`${name}-input`));
  },
  tableType(name, schema) {
    return upperFirst(this.tableName(name, schema));
  },
  column(name, _table, _schema) {
    return camelCase(name);
  },
  singleRelationByKeys(detailedKeys, table, schema) {
    var _this = this;

    return camelCase(`${this.tableName(table, schema)}-by-${detailedKeys.map(function (key) {
      return _this.column(key.column, key.table, key.schema);
    }).join("-and-")}`);
  },
  updateByKeys(detailedKeys, table, schema) {
    var _this2 = this;

    return camelCase(`update-${this.tableName(table, schema)}-by-${detailedKeys.map(function (key) {
      return _this2.column(key.column, key.table, key.schema);
    }).join("-and-")}`);
  },
  deleteByKeys(detailedKeys, table, schema) {
    var _this3 = this;

    return camelCase(`delete-${this.tableName(table, schema)}-by-${detailedKeys.map(function (key) {
      return _this3.column(key.column, key.table, key.schema);
    }).join("-and-")}`);
  },
  updateNode(name, _schema) {
    return camelCase(`update-${_pluralize2.default.singular(name)}`);
  },
  deleteNode(name, _schema) {
    return camelCase(`delete-${_pluralize2.default.singular(name)}`);
  },
  updateByKeysInputType(detailedKeys, name, _schema) {
    var _this4 = this;

    return upperFirst(camelCase(`update-${_pluralize2.default.singular(name)}-by-${detailedKeys.map(function (key) {
      return _this4.column(key.column, key.table, key.schema);
    }).join("-and-")}-input`));
  },
  deleteByKeysInputType(detailedKeys, name, _schema) {
    var _this5 = this;

    return upperFirst(camelCase(`delete-${_pluralize2.default.singular(name)}-by-${detailedKeys.map(function (key) {
      return _this5.column(key.column, key.table, key.schema);
    }).join("-and-")}-input`));
  },
  updateNodeInputType(name, _schema) {
    return upperFirst(camelCase(`update-${_pluralize2.default.singular(name)}-input`));
  },
  deleteNodeInputType(name, _schema) {
    return upperFirst(camelCase(`delete-${_pluralize2.default.singular(name)}-input`));
  },
  manyRelationByKeys(detailedKeys, table, schema) {
    var _this6 = this;

    return camelCase(`${this.pluralize(this.tableName(table, schema))}-by-${detailedKeys.map(function (key) {
      return _this6.column(key.column, key.table, key.schema);
    }).join("-and-")}`);
  },
  edge(typeName) {
    return upperFirst(camelCase(`${(0, _pluralize2.default)(typeName)}-edge`));
  },
  edgeField(name, _schema) {
    return camelCase(`${_pluralize2.default.singular(name)}-edge`);
  },
  connection(typeName) {
    return upperFirst(camelCase(`${this.pluralize(typeName)}-connection`));
  },
  scalarFunctionConnection(procName, _procSchema) {
    return upperFirst(camelCase(`${procName}-connection`));
  },
  scalarFunctionEdge(procName, _procSchema) {
    return upperFirst(camelCase(`${procName}-edge`));
  },
  createField(name, _schema) {
    return camelCase(`create-${_pluralize2.default.singular(name)}`);
  },
  createInputType(name, _schema) {
    return upperFirst(camelCase(`create-${_pluralize2.default.singular(name)}-input`));
  },
  createPayloadType(name, _schema) {
    return upperFirst(camelCase(`create-${_pluralize2.default.singular(name)}-payload`));
  },
  updatePayloadType(name, _schema) {
    return upperFirst(camelCase(`update-${_pluralize2.default.singular(name)}-payload`));
  },
  deletePayloadType(name, _schema) {
    return upperFirst(camelCase(`delete-${_pluralize2.default.singular(name)}-payload`));
  }
};

var postGraphQLInflection = exports.postGraphQLInflection = (0, _assign2.default)({}, defaultInflection, {
  enumName(value) {
    return constantCase(value);
  }
});

var postGraphQLClassicIdsInflection = exports.postGraphQLClassicIdsInflection = (0, _assign2.default)({}, postGraphQLInflection, {
  column(name, _table, _schema) {
    return name === "id" ? "rowId" : camelCase(name);
  }
});
//# sourceMappingURL=inflections.js.map