"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.postGraphQLClassicIdsInflection = exports.postGraphQLInflection = exports.defaultInflection = undefined;

var _assign = require("babel-runtime/core-js/object/assign");

var _assign2 = _interopRequireDefault(_assign);

var _pluralize = require("pluralize");

var _pluralize2 = _interopRequireDefault(_pluralize);

var _upperFirst = require("lodash/upperFirst");

var _upperFirst2 = _interopRequireDefault(_upperFirst);

var _camelCase = require("lodash/camelCase");

var _camelCase2 = _interopRequireDefault(_camelCase);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const constantCaseAll = str => str.replace(/[^a-zA-Z0-9_]+/g, "_").replace(/[A-Z]+/g, "_$&").replace(/__+/g, "_").replace(/^[^a-zA-Z0-9]+/, "").replace(/^[0-9]/, "_$&") // GraphQL enums must not start with a number
.toUpperCase();


const formatInsideUnderscores = fn => str => {
  const matches = str.match(/^(_*)([\s\S]*?)(_*)$/);
  if (!matches) {
    throw new Error("Impossible?"); // Satiate Flow
  }
  const [, start, middle, end] = matches;
  return `${start}${fn(middle)}${end}`;
};

const upperFirst = formatInsideUnderscores(_upperFirst2.default);
const camelCase = formatInsideUnderscores(_camelCase2.default);
const constantCase = formatInsideUnderscores(constantCaseAll);

const defaultInflection = exports.defaultInflection = {
  pluralize: _pluralize2.default,
  argument(name, index) {
    return camelCase(name || `arg${index}`);
  },
  orderByType(typeName) {
    return upperFirst(camelCase(`${(0, _pluralize2.default)(typeName)}-order-by`));
  },
  orderByEnum(name, ascending, _table, _schema) {
    return constantCase(`${name}_${ascending ? "asc" : "desc"}`);
  },
  domainType(name) {
    return upperFirst(camelCase(name));
  },
  enumName(value) {
    return value;
  },
  enumType(name) {
    return upperFirst(camelCase(name));
  },
  conditionType(typeName) {
    return upperFirst(camelCase(`${typeName}-condition`));
  },
  inputType(typeName) {
    return upperFirst(camelCase(`${typeName}-input`));
  },
  rangeBoundType(typeName) {
    return upperFirst(camelCase(`${typeName}-range-bound`));
  },
  rangeType(typeName) {
    return upperFirst(camelCase(`${typeName}-range`));
  },
  patchType(typeName) {
    return upperFirst(camelCase(`${typeName}-patch`));
  },
  patchField(itemName) {
    return camelCase(`${itemName}-patch`);
  },
  tableName(name, _schema) {
    return camelCase(_pluralize2.default.singular(name));
  },
  tableNode(name, _schema) {
    return camelCase(_pluralize2.default.singular(name));
  },
  allRows(name, schema) {
    return camelCase(`all-${this.pluralize(this.tableName(name, schema))}`);
  },
  functionName(name, _schema) {
    return camelCase(name);
  },
  functionPayloadType(name, _schema) {
    return upperFirst(camelCase(`${name}-payload`));
  },
  functionInputType(name, _schema) {
    return upperFirst(camelCase(`${name}-input`));
  },
  tableType(name, schema) {
    return upperFirst(this.tableName(name, schema));
  },
  column(name, _table, _schema) {
    return camelCase(name);
  },
  singleRelationByKeys(detailedKeys, table, schema) {
    return camelCase(`${this.tableName(table, schema)}-by-${detailedKeys.map(key => this.column(key.column, key.table, key.schema)).join("-and-")}`);
  },
  updateByKeys(detailedKeys, table, schema) {
    return camelCase(`update-${this.tableName(table, schema)}-by-${detailedKeys.map(key => this.column(key.column, key.table, key.schema)).join("-and-")}`);
  },
  deleteByKeys(detailedKeys, table, schema) {
    return camelCase(`delete-${this.tableName(table, schema)}-by-${detailedKeys.map(key => this.column(key.column, key.table, key.schema)).join("-and-")}`);
  },
  updateNode(name, _schema) {
    return camelCase(`update-${_pluralize2.default.singular(name)}`);
  },
  deleteNode(name, _schema) {
    return camelCase(`delete-${_pluralize2.default.singular(name)}`);
  },
  updateByKeysInputType(detailedKeys, name, _schema) {
    return upperFirst(camelCase(`update-${_pluralize2.default.singular(name)}-by-${detailedKeys.map(key => this.column(key.column, key.table, key.schema)).join("-and-")}-input`));
  },
  deleteByKeysInputType(detailedKeys, name, _schema) {
    return upperFirst(camelCase(`delete-${_pluralize2.default.singular(name)}-by-${detailedKeys.map(key => this.column(key.column, key.table, key.schema)).join("-and-")}-input`));
  },
  updateNodeInputType(name, _schema) {
    return upperFirst(camelCase(`update-${_pluralize2.default.singular(name)}-input`));
  },
  deleteNodeInputType(name, _schema) {
    return upperFirst(camelCase(`delete-${_pluralize2.default.singular(name)}-input`));
  },
  manyRelationByKeys(detailedKeys, table, schema) {
    return camelCase(`${this.pluralize(this.tableName(table, schema))}-by-${detailedKeys.map(key => this.column(key.column, key.table, key.schema)).join("-and-")}`);
  },
  edge(typeName) {
    return upperFirst(camelCase(`${(0, _pluralize2.default)(typeName)}-edge`));
  },
  edgeField(name, _schema) {
    return camelCase(`${_pluralize2.default.singular(name)}-edge`);
  },
  connection(typeName) {
    return upperFirst(camelCase(`${this.pluralize(typeName)}-connection`));
  },
  scalarFunctionConnection(procName, _procSchema) {
    return upperFirst(camelCase(`${procName}-connection`));
  },
  scalarFunctionEdge(procName, _procSchema) {
    return upperFirst(camelCase(`${procName}-edge`));
  },
  createField(name, _schema) {
    return camelCase(`create-${_pluralize2.default.singular(name)}`);
  },
  createInputType(name, _schema) {
    return upperFirst(camelCase(`create-${_pluralize2.default.singular(name)}-input`));
  },
  createPayloadType(name, _schema) {
    return upperFirst(camelCase(`create-${_pluralize2.default.singular(name)}-payload`));
  },
  updatePayloadType(name, _schema) {
    return upperFirst(camelCase(`update-${_pluralize2.default.singular(name)}-payload`));
  },
  deletePayloadType(name, _schema) {
    return upperFirst(camelCase(`delete-${_pluralize2.default.singular(name)}-payload`));
  }
};

const postGraphQLInflection = exports.postGraphQLInflection = (0, _assign2.default)({}, defaultInflection, {
  enumName(value) {
    return constantCase(value);
  }
});

const postGraphQLClassicIdsInflection = exports.postGraphQLClassicIdsInflection = (0, _assign2.default)({}, postGraphQLInflection, {
  column(name, _table, _schema) {
    return name === "id" ? "rowId" : camelCase(name);
  }
});
//# sourceMappingURL=inflections.js.map